import React, {ReactNode, useContext} from 'react';
import {View, StyleSheet} from 'react-native';
import Button from '../Button/Button';
import Text, {textColors} from '../Text/Text';
import ThemeContext from '../ThemeContext/ThemeContext';
import {
  SEMANTIC_RED_PRIMARY,
  SEMANTIC_SUCCESS_GREEN_PRIMARY,
} from '../UikitUtils/colors';
import {primaryColor, secondaryColor} from '../UikitUtils/themeHelper';

const styles = StyleSheet.create({
  containerStyle: {
    borderRadius: 4,
    paddingVertical: 8,
    paddingHorizontal: 8,
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center',
  },
  textStyle: {
    fontSize: 12,
  },
});

type DefaultProps = {
  type: 'primary' | 'success' | 'secondary' | 'error';
};
const defaultProps: DefaultProps = {
  type: 'primary',
};

type Props = {
  children: ReactNode;
  onClick?: () => void;
  disabled?: boolean;
} & typeof defaultProps;
const Badge = ({type, children, onClick, disabled}: Props) => {
  const {theme} = useContext(ThemeContext);

  let backgroundColor;
  let textColor: textColors = 'white';

  if (type === 'primary') {
    backgroundColor = primaryColor(theme);
    textColor = 'white';
  } else if (type === 'secondary') {
    backgroundColor = secondaryColor(theme);
    textColor = 'white';
  } else if (type === 'success') {
    backgroundColor = SEMANTIC_SUCCESS_GREEN_PRIMARY;
    textColor = 'white';
  }
  if (type === 'error') {
    backgroundColor = SEMANTIC_RED_PRIMARY;
    textColor = 'white';
  }
  return (
    <Button disabled={disabled} onClick={onClick} type="link">
      <View style={[styles.containerStyle, {backgroundColor}]}>
        <Text color={textColor} overrideStyle={[styles.textStyle]}>
          {children}
        </Text>
      </View>
    </Button>
  );
};

Badge.defaultProps = defaultProps;

export default Badge;
