import React from 'react';
import {Dimensions, ScrollView} from 'react-native';
import {action} from '@storybook/addon-actions';
import Button from './Button';
import {ButtonComponent} from '../UikitUtils/storiesHelper';
import Flex from '../Flex/Flex';
import {STORIES_PREFIX} from '../UikitUtils/constants';
import {GRAY_95} from '../UikitUtils/colors';
import {ComponentMeta, ComponentStory} from '@storybook/react';

const {height} = Dimensions.get('window');

export const Basic = () => {
  return (
    <ScrollView style={{height, backgroundColor: GRAY_95}}>
      <Flex overrideStyle={{paddingTop: 30, paddingBottom: 20}}>
        <ButtonComponent label="Primary Button">
          <Button onClick={action('clicked-primary')}>Primary Button</Button>
        </ButtonComponent>

        <ButtonComponent label="Primary Button Disabled">
          <Button disabled onClick={action('clicked-primary-disabled')}>
            Primary Button Disabled
          </Button>
        </ButtonComponent>

        <ButtonComponent label="Secondary Button">
          <Button type="secondary" onClick={action('clicked-Secondary')}>
            Secondary Button
          </Button>
        </ButtonComponent>

        <ButtonComponent label="Secondary Button Disabled">
          <Button
            type="secondary"
            disabled
            onClick={action('clicked-Secondary-disabled')}
          >
            Secondary Button Disabled
          </Button>
        </ButtonComponent>

        <ButtonComponent label="Success Button">
          <Button type="success" onClick={action('clicked-success')}>
            Success Button
          </Button>
        </ButtonComponent>

        <ButtonComponent label="Success Button Disabled">
          <Button
            type="success"
            disabled
            onClick={action('clicked-success-disabled')}
          >
            Success Button Disabled
          </Button>
        </ButtonComponent>

        <ButtonComponent label="Tertiary Button">
          <Button type="tertiary" onClick={action('clicked-tertiary')}>
            Tertiary Button
          </Button>
        </ButtonComponent>

        <ButtonComponent label="Tertiary Button Disabled">
          <Button
            type="tertiary"
            disabled
            onClick={action('clicked-tertiary-disabled')}
          >
            Tertiary Button Disabled
          </Button>
        </ButtonComponent>

        <ButtonComponent label="Loading Button Button">
          <Button loading onClick={action('clicked-Loading')}>
            Loading Button
          </Button>
        </ButtonComponent>

        <ButtonComponent label="Loading Button Disabled">
          <Button loading disabled onClick={action('clicked-Loading-disabled')}>
            Loading Button Disabled
          </Button>
        </ButtonComponent>

        <ButtonComponent label="Flat Button Button">
          <Button flat onClick={action('clicked-Flat')}>
            Flat Button
          </Button>
        </ButtonComponent>

        <ButtonComponent label="Flat Button Disabled">
          <Button flat disabled onClick={action('clicked-Flat-disabled')}>
            Flat Button Disabled
          </Button>
        </ButtonComponent>

        <ButtonComponent label="Link Button Button">
          <Button type="link" onClick={action('clicked-Link')}>
            Link Button
          </Button>
        </ButtonComponent>

        <ButtonComponent label="Link Button Disabled">
          <Button
            type="link"
            disabled
            onClick={action('clicked-Link-disabled')}
          >
            Link Button Disabled
          </Button>
        </ButtonComponent>
      </Flex>
    </ScrollView>
  );
};

const Template: ComponentStory<typeof Button> = args => (
  <Button {...args}>Text with dynamic size attribute</Button>
);

export const Playground = Template.bind({});

export default {
  title: `${STORIES_PREFIX.components}/Button`,
  component: Button,
} as ComponentMeta<typeof Button>;
