import React, {useContext, useRef} from 'react';
import {
  ActivityIndicator,
  TouchableOpacity,
  View,
  ViewStyle,
} from 'react-native';
import {OverrideStyle} from '../Flex/Flex';
import Text from '../Text/Text';
import ThemeContext from '../ThemeContext/ThemeContext';
import {primaryColor} from '../UikitUtils/themeHelper';
import {buttonColorHelper, buttonHelper, getTextColors} from './ButtonHelper';
import {styles} from './buttonStyles';

// code split for ViewStyle as its not madatory for other components required

export type ButtonType = 'primary' | 'secondary' | 'link' | 'success' | 'tertiary';

export const isButtonTypeKey = (str: string | undefined): str is ButtonType =>
  str !== undefined;
export const isOverrideStyleArray = (
  str: OverrideStyle | undefined,
): str is ViewStyle[] => str !== undefined;

const defaultProps = {
  type: 'primary',
  textSize: 16,
};

type Props = {
  children: import('react').ReactChild;
  flex?: number;
  overrideStyle?: ViewStyle[] | ViewStyle;
  onClick?: (arg: any) => void;
  flat?: boolean;
  curved?: boolean;
  disabled?: boolean;
  testID?: string;
  loading?: boolean;
  contain?: boolean;
  type: ButtonType;
} & typeof defaultProps;

const Button = ({
  flat,
  overrideStyle,
  onClick,
  children,
  curved,
  disabled,
  flex,
  testID,
  loading,
  contain,
  textSize,
  type,
}: Props) => {
  const {theme} = useContext(ThemeContext);
  const ref = useRef(null);
  let styleArray = [styles.common];

  const textColor = getTextColors({
    type,
    theme,
    disabled,
  });

  buttonColorHelper({
    styleArray,
    theme,
    type,
  });

  buttonHelper(styleArray, flex, curved, flat, disabled, theme, type, contain);

  if (overrideStyle) {
    if (isOverrideStyleArray(overrideStyle) && Array.isArray(overrideStyle)) {
      styleArray = [...styleArray, ...overrideStyle];
    } else {
      styleArray.push(overrideStyle);
    }
  }

  return (
    <TouchableOpacity
      ref={ref}
      disabled={disabled || loading}
      onPress={onClick}
      style={styleArray}
      testID={testID}
    >
      <View style={styles.indicatorDirection}>
        {loading && (
          <ActivityIndicator
            size="small"
            color={primaryColor(theme)}
            style={styles.indicator}
          />
        )}
        {typeof children === 'string' || typeof children === 'number' ? (
          <Text bold size={textSize} color={textColor}>
            {children}
          </Text>
        ) : (
          children
        )}
      </View>
    </TouchableOpacity>
  );
};

Button.defaultProps = defaultProps;

export default Button;
