/* eslint sonarjs/cognitive-complexity: ["error", 46] */
import {ViewStyle} from 'react-native';
import {textColors} from '../Text/Text';
import {SEMANTIC_SUCCESS_GREEN_PRIMARY} from '../UikitUtils/colors';
import {
  defaultButtonCurved,
  primaryButtonColor,
  primaryButtonTextColor,
  primaryColor,
} from '../UikitUtils/themeHelper';
import type {ThemeType} from '../UikitUtils/themeTypes';
import {isButtonTypeKey, ButtonType} from './Button';
import {styles} from './buttonStyles';

type buttonColorType = {
  styleArray: ViewStyle[];
  type: ButtonType;
  theme: ThemeType;
};

export const buttonColorHelper = ({
  styleArray,
  type,
  theme,
}: buttonColorType) => {
  if (isButtonTypeKey(type)) {
    switch (type) {
      case 'primary':
        styleArray.push({backgroundColor: primaryButtonColor(theme)});
        break;
      case 'secondary':
        let borderColor = primaryButtonColor(theme);
        styleArray.push(styles.secondary, {borderColor});
        break;
      case 'success':
        styleArray.push({backgroundColor: SEMANTIC_SUCCESS_GREEN_PRIMARY});
        break;
      case 'tertiary':
        styleArray.push(styles.tertiary);
        break;
      case 'link':
        styleArray.push(styles.link);
        break;
      default:
        styleArray.push({backgroundColor: primaryColor(theme)});
        break;
    }
  }
};

export const buttonHelper = (
  styleArray: ViewStyle[],
  flex: number | undefined,
  curved: boolean | undefined,
  flat: boolean | undefined,
  disabled: boolean | undefined,
  theme: ThemeType,
  type: ButtonType,
  contain: boolean | undefined,
) => {
  if (flex) {
    styleArray.push({flex});
  }

  if (defaultButtonCurved(theme) || curved) {
    styleArray.push(styles.curved);
  } else if (flat) {
    styleArray.push(styles.flat);
  }

  if (disabled && type === 'link') {
    styleArray.push(styles.link);
  } else if (disabled && type === 'secondary') {
    styleArray.push(styles.secondaryDisabled);
  } else if(disabled && type === 'tertiary')  {
    styleArray.push(styles.tertiaryDisabled);

  } else if (disabled) {
    styleArray.push(styles.disabled);
  }

  if (contain) {
    // not working need to implement container like component
    styleArray.push(styles.contain);
  }
};

type GetTextColorProp = {
  theme: ThemeType;
  type: ButtonType;
  disabled?: boolean;
};

export const getTextColors = ({type, theme, disabled}: GetTextColorProp) => {
  let textColor: textColors | undefined = 'white';

  if (type !== 'link' && type === 'primary') {
    textColor = primaryButtonTextColor(theme);
  }
  if (type === 'secondary' && disabled) {
    textColor = 'gray';
  } else if (type === 'secondary') {
    textColor = 'theme';
  }

  if (type === 'link') {
    textColor = 'link';
  }
  if (type === 'tertiary' && disabled) {
    textColor = 'gray';
  } else if (type === 'tertiary') {
    textColor = 'black';
  }
  return textColor;
};
