import React, { useMemo } from 'react';
import { View, StyleSheet, TouchableOpacity } from 'react-native';
import type { GestureResponderEvent } from 'react-native';
import { MONTH } from './CalendarHeader';
import Text from '../Text/Text';
import { BORDER_COLOR } from '../UikitUtils/colors';
import { CommonDefaultProps } from './Calendar';
import { commonCalendarStyle } from './CalendarStyle';

const styles = StyleSheet.create({
  monthContainer: {
    flexDirection: 'row',
    flexWrap: 'wrap',
    width: 260,
    position: 'absolute',
    zIndex: 1,
    backgroundColor: '#ffffff',
    borderWidth: 1,
    borderColor: BORDER_COLOR,
    borderRadius: 4,
  },
  month: {
    padding: 8,
    width: '33.3333%',
    justifyContent: 'center',
    display: 'flex',
    flexDirection: 'column',
  },
});

type Props = {
  handleSelectMonth: (e: GestureResponderEvent, arg: number) => void;
} & CommonDefaultProps;

const Month = (
  { handleSelectMonth, align }: Props,
  ref: React.LegacyRef<View>,
) => {
  const monthContainerStyle = useMemo(() => {
    switch (align) {
      case 'topRight':
        return StyleSheet.flatten([
          styles.monthContainer,
          commonCalendarStyle.topRightYearOrMonthContainer,
        ]);
      case 'bottomLeft':
        return StyleSheet.flatten([
          styles.monthContainer,
          commonCalendarStyle.bottomContainer,
        ]);
      default:
        return StyleSheet.flatten([
          styles.monthContainer,
          commonCalendarStyle.topContainer,
        ]);
    }
  }, []);
  return (
    <View ref={ref} style={monthContainerStyle} testID="monthContainer">
      {MONTH.map((month, index) => (
        <TouchableOpacity
          testID={`handleSelectMonthId${index}`}
          activeOpacity={1}
          key={month}
          style={styles.month}
          onPress={(e) => handleSelectMonth(e, index)}
        >
          <Text>{month}</Text>
        </TouchableOpacity>
      ))}
    </View>
  );
};

export default React.forwardRef(Month);
