import React, {useMemo, useState} from 'react';
import {StyleSheet, TouchableOpacity} from 'react-native';
import type {GestureResponderEvent} from 'react-native';
import {
  CommonDefaultProps,
  convertDateStrtoDateObject,
  getDateString,
  getRequiredPartialDateObj,
} from './Calendar';
import type {InititalDateType} from './Calendar';
import InputText from '../InputText/InputText';
import {BORDER_COLOR} from '../UikitUtils/colors';
import Button from '../Button/Button';
import {commonCalendarStyle} from './CalendarStyle';

type Props = {
  date: InititalDateType;
  setDate: (arg: InititalDateType) => void;
  handleCloseYear: (e: GestureResponderEvent) => void;
};
const styles = StyleSheet.create({
  yearContainer: {
    minWidth: 252,
    position: 'absolute',
    zIndex: 1,
    height: 220,
    backgroundColor: '#ffffff',
    borderWidth: 1,
    borderColor: BORDER_COLOR,
    borderRadius: 4,
    justifyContent: 'center',
    alignItems: 'center',
  },
  button: {
    width: 86,
    marginTop: 24,
  },
});
const Year = (
  {date, setDate, handleCloseYear, align}: Props & CommonDefaultProps,
  ref: React.LegacyRef<TouchableOpacity>,
) => {
  const yearContainerStyle = useMemo(() => {
    switch (align) {
      case 'topRight':
        return StyleSheet.flatten([
          styles.yearContainer,
          commonCalendarStyle.topRightYearOrMonthContainer,
        ]);
      case 'bottomLeft':
        return StyleSheet.flatten([
          styles.yearContainer,
          commonCalendarStyle.bottomContainer,
        ]);
      default:
        return StyleSheet.flatten([
          styles.yearContainer,
          commonCalendarStyle.topContainer,
        ]);
    }
  }, []);
  const year = date ? date.year : new Date().getFullYear();
  const [chosenYear, setYear] = useState(`${year}`);

  const handleTouchablePress = (e: GestureResponderEvent) =>
    e.stopPropagation();
  const handleYearChange = (value: string) => {
    const parsedValue = parseInt(value, 10);
    if (!Number.isNaN(parsedValue) && parsedValue > 19 && parsedValue < 9999) {
      setYear(`${parsedValue}`);
    }
  };

  const handleDateUpdate = (e: GestureResponderEvent) => {
    const parsedValue = parseInt(chosenYear, 10);
    const partialDateObj = getRequiredPartialDateObj(date);
    const dateString = getDateString({...partialDateObj, year: parsedValue});
    const dateObject = convertDateStrtoDateObject(dateString);
    setDate(dateObject);
    handleCloseYear(e);
  };
  return (
    <TouchableOpacity
      activeOpacity={1}
      ref={ref}
      style={yearContainerStyle}
      onPress={handleTouchablePress}
      testID="yearContainer"
    >
      <InputText
        value={chosenYear}
        onChange={handleYearChange}
        placeholder="Enter the year"
        align="center"
      />
      <Button
        onClick={handleDateUpdate}
        overrideStyle={styles.button}
        testID="setYearBtn"
      >
        Set
      </Button>
    </TouchableOpacity>
  );
};

export default React.forwardRef(Year);
