import React from 'react';
import { FlatList, TouchableOpacity, StyleSheet } from 'react-native';
import Flex from '../Flex/Flex';
import Text, { textColors } from '../Text/Text';
import { getDateString, keyValueType } from './CalendarData';

const uikitStyles = StyleSheet.create({
  listItem: {
    paddingVertical: 6,
  },

  titleContainer: {
    width: 100,
  },
  columnStyle: {
    padding: 10,
  },
});

interface FlatListGeneratorProps {
  dataSource: keyValueType[];
  selectHandler: (value: number) => void;
  selected: number;
  numColumns?: number;
}

type RenderItemProps = {
  selectHandler: (value: number) => void;
  selected: number;
  item: keyValueType;
};

const RenderItem = ({ item, selected, selectHandler }: RenderItemProps) => {
  const color: textColors = selected === item.value ? 'theme' : 'gray';
  return (
    <TouchableOpacity
      onPress={() => selectHandler(item.value)}
      style={uikitStyles.listItem}
    >
      <Flex center overrideStyle={uikitStyles.titleContainer}>
        <Text color={color} bold={selected === item.value}>
          {item.label}
        </Text>
      </Flex>
    </TouchableOpacity>
  );
};

const FlatListGenerator = ({
  dataSource,
  selectHandler,
  selected,
  numColumns,
}: FlatListGeneratorProps) => {
  const columnWrapperStyle = !!numColumns && uikitStyles.columnStyle;
  return (
    <FlatList
      showsVerticalScrollIndicator={false}
      data={dataSource}
      renderItem={({ item }) => (
        <RenderItem
          item={item}
          selected={selected}
          selectHandler={selectHandler}
        />
      )}
      keyExtractor={(item) => item.label}
      numColumns={numColumns}
      columnWrapperStyle={columnWrapperStyle}
    />
  );
};

export default FlatListGenerator;

export const dateHelper = (date: string, month: number, year: number) => {
  const currDate = new Date(date);
  currDate.setMonth(month - 1);
  currDate.setFullYear(year);
  return getDateString(currDate);
};
