import React, {useMemo, useState} from 'react';
import {Calendar} from 'react-native-calendars';
import {View, StyleSheet} from 'react-native';
import CalendarHeader from '../Calendar/CalendarHeader';
import Flex from '../Flex/Flex';
import Modal from '../Modal/Modal';
import {dateString, currentMonth, currentYear} from './CalendarData';
import {dateHelper} from './CalendarHelpers';
import SvgChevronLeft from '../icons/SvgChevronLeft';
import SvgChevronRight from '../icons/SvgChevronRight';
import Button from '../Button/Button';
import {SEMANTIC_INFO_BLUE_PRIMARY, WHITE} from '../UikitUtils/colors';
import MonthList from './MonthList';
import YearList from './YearList';

// const screenWidth = Dimensions.get('window').width;

const uikitStyles = StyleSheet.create({
  overAll: {
    // height: '100%',
    // width: screenWidth,
  },
  calendar: {
    borderTopLeftRadius: 10,
    borderTopRightRadius: 10,
    borderBottomWidth: 0,
  },
  BtnContainer: {
    backgroundColor: WHITE,
    paddingHorizontal: 16,
    paddingTop: 34,
    paddingBottom: 6,
  },
  divider: {
    width: 16,
  },
});

const renderArrow = (direction: 'left' | 'right') => {
  if (direction === 'right') {
    return <SvgChevronRight />;
  }
  return <SvgChevronLeft />;
};

type Props = {
  open: boolean;
  onClose: () => void;
  primaryButtonName: string;
  secondarButtonName: string;
  onConfirm: (date: string) => void;
};

const CalendarNative = ({
  open,
  onClose,
  primaryButtonName,
  secondarButtonName,
  onConfirm,
}: Props) => {
  const [date, setDate] = useState(dateString);
  const [month, setMonth] = useState(currentMonth + 1);
  const [year, setYear] = useState(currentYear);
  const [openYear, setOpenYear] = useState(false);
  const [openMonth, setOpenMonth] = useState(false);

  const newDate = useMemo(() => dateHelper(date, month, year), [
    date,
    month,
    year,
  ]);

  const handleConfirm = () => {
    onConfirm(date);
    onClose();
  };

  const handleDate = (day: any) => {
    setDate(day.dateString);
  };

  return (
    <Modal animationType="fade" open={open} onClose={onClose}>
      <View style={{width: '90%'}}>
        {openMonth && (
          <MonthList
            closeHandler={() => setOpenMonth(false)}
            getMonth={setMonth}
            selectedMonth={month}
          />
        )}
        {openYear && (
          <View
            style={{
              justifyContent: 'flex-end',
            }}
          >
            <YearList
              closeHandler={() => setOpenYear(false)}
              getYear={setYear}
              selectedYear={year}
            />
          </View>
        )}
        <Flex overrideStyle={uikitStyles.overAll}>
          {!openMonth && !openYear && (
            <Calendar
              onDayPress={handleDate}
              onMonthChange={curMon => {
                setMonth(curMon.month);
              }}
              maxDate={new Date().toDateString()}
              current={newDate}
              markedDates={{
                [date]: {
                  selected: true,
                  selectedColor: SEMANTIC_INFO_BLUE_PRIMARY,
                },
              }}
              monthFormat="yyyy mm"
              renderHeader={currDate => (
                <CalendarHeader
                  date={currDate}
                  handleOpenMonth={() => setOpenMonth(true)}
                  handleOpenYear={() => setOpenYear(true)}
                />
              )}
              style={uikitStyles.calendar}
              renderArrow={direction => renderArrow(direction)}
            />
          )}
          {!openMonth && !openYear && (
            <Flex row overrideStyle={uikitStyles.BtnContainer}>
              <Flex flex={1}>
                <Button type="secondary" onClick={onClose}>
                  {secondarButtonName}
                </Button>
              </Flex>
              <View style={uikitStyles.divider} />
              <Flex flex={1}>
                <Button onClick={handleConfirm}>{primaryButtonName}</Button>
              </Flex>
            </Flex>
          )}
        </Flex>
      </View>
    </Modal>
  );
};

export default CalendarNative;
