import React from 'react';
import {StyleSheet} from 'react-native';
import Flex from '../Flex/Flex';
import Text from '../Text/Text';
import {WHITE} from '../UikitUtils/colors';
import {MONTH_LIST} from './CalendarData';
import FlatListGenerator from './CalendarHelpers';

interface MonthListProps {
  getMonth: (value: number) => void;
  closeHandler: () => void;
  selectedMonth: number;
}

const uikitStyles = StyleSheet.create({
  container: {
    backgroundColor: WHITE,
    borderTopLeftRadius: 10,
    borderTopRightRadius: 10,
  },
  title: {
    paddingVertical: 10,
  },
});

const MonthList = ({getMonth, closeHandler, selectedMonth}: MonthListProps) => {
  const setMonthHandler = (val: number) => {
    getMonth(val);
    closeHandler();
  };
  return (
    <Flex overrideStyle={uikitStyles.container} center>
      <Text bold size={18} overrideStyle={uikitStyles.title}>
        Select Month
      </Text>
      <FlatListGenerator
        dataSource={MONTH_LIST}
        selectHandler={setMonthHandler}
        selected={selectedMonth}
        numColumns={3}
      />
    </Flex>
  );
};

export default MonthList;
