import React, {useMemo} from 'react';
import {StyleSheet} from 'react-native';
import Flex from '../Flex/Flex';
import Text from '../Text/Text';
import {WHITE} from '../UikitUtils/colors';
import {yearOptions} from './CalendarData';
import FlatListGenerator from './CalendarHelpers';

interface YearListProps {
  getYear: (value: number) => void;
  closeHandler: () => void;
  selectedYear: number;
}

const uikitStyles = StyleSheet.create({
  container: {
    backgroundColor: WHITE,
    borderTopLeftRadius: 10,
    borderTopRightRadius: 10,
    maxHeight: '80%',    
  },
  title: {
    paddingVertical: 10,
  },
});

const YearList = ({getYear, closeHandler, selectedYear}: YearListProps) => {
  const setYearHandler = (val: number) => {
    getYear(val);
    closeHandler();
  };
  const years = useMemo(() => yearOptions(), []);
  return (
    <Flex overrideStyle={uikitStyles.container} center>
      <Text bold size={18} overrideStyle={uikitStyles.title}>
        Select Year
      </Text>
      <FlatListGenerator
        dataSource={years}
        selectHandler={setYearHandler}
        selected={selectedYear}
      />
    </Flex>
  );
};

export default YearList;
