/* eslint sonarjs/cognitive-complexity: ["error", 24] */
import React from 'react';
import {TouchableOpacity, StyleSheet, View} from 'react-native';
import {
  WHITE,
  BLACK,
  SEMANTIC_INFO_BLUE_PRIMARY,
  SEMANTIC_RED_PRIMARY,
  SEMANTIC_SUCCESS_GREEN_PRIMARY,
} from '../UikitUtils/colors';

type ViewStyle = import('react-native').ViewStyle;

type Styles = {
  normal: ViewStyle;
  noDrop: ViewStyle;
  gradientCard: ViewStyle;
  alignNormal: ViewStyle;
  alignCenter: ViewStyle;
  alignStretch: ViewStyle;
  curved: ViewStyle;
  expanded: ViewStyle;
  flat: ViewStyle;
  primary: ViewStyle;
  info: ViewStyle;
  error: ViewStyle;
  success: ViewStyle;
};

const styles = StyleSheet.create<Styles>({
  normal: {
    backgroundColor: WHITE,
  },
  noDrop: {
    shadowOffset: {width: 0, height: 0},
    shadowRadius: 0,
    shadowOpacity: 0,
    elevation: 0,
  },
  gradientCard: {
    borderRadius: 10,
    elevation: 5,
    shadowColor: BLACK,
    shadowOffset: {width: 0, height: 3},
    shadowOpacity: 0.06,
    shadowRadius: 10,
  },
  alignNormal: {
    alignItems: 'flex-start',
    justifyContent: 'flex-start',
  },
  alignCenter: {
    alignItems: 'center',
    justifyContent: 'center',
  },
  alignStretch: {
    alignItems: 'stretch',
  },
  curved: {
    borderRadius: 28,
  },
  expanded: {
    flex: 1,
    flexDirection: 'row',
  },
  flat: {
    borderRadius: 0,
  },
  primary: {
    backgroundColor: WHITE,
  },
  info: {
    backgroundColor: SEMANTIC_INFO_BLUE_PRIMARY,
  },
  error: {
    backgroundColor: SEMANTIC_RED_PRIMARY,
  },
  success: {
    backgroundColor: SEMANTIC_SUCCESS_GREEN_PRIMARY,
  },
});

const defaultProps = {
  normal: true,
  align: 'center',
  type: 'primary',
};

type AlignType = 'normal' | 'center' | 'stretch';
type cardType = 'primary' | 'info' | 'success' | 'error';

type Props = {
  children: import('react').ReactChild;
  noDrop?: boolean;
  align?: AlignType;
  curved?: boolean;
  overrideStyle?: ViewStyle;
  flex?: number;
  disabled?: boolean;
  expanded?: boolean;
  flat?: boolean;
  // outline?: boolean;
  overrideContainerStyle?: ViewStyle;
  onClick?: (arg: any) => void;
  testID?: string;
  type?: cardType;
} & typeof defaultProps;

const Card = ({
  children,
  onClick,
  noDrop,
  align,
  curved,
  overrideStyle,
  flex,
  disabled,
  expanded,
  flat,
  // outline,
  overrideContainerStyle,
  testID,
  type,
}: Props) => {
  // const {theme} = useContext(ThemeContext);
  const colorArray = [{}];
  const gradCardStyleArray = [styles.gradientCard];
  const containerStyle = [];

  if (flex) {
    gradCardStyleArray.push({flex});
    containerStyle.push({flex});
  }
  if (type === 'primary') {
    colorArray.push(styles.primary);
  } else if (type === 'info') {
    colorArray.push(styles.info);
  } else if (type === 'error') {
    colorArray.push(styles.error);
  } else if (type === 'success') {
    colorArray.push(styles.success);
  } else {
    colorArray.push({backgroundColor: WHITE});
  }

  if (align === 'normal') {
    gradCardStyleArray.push(styles.alignNormal);
    containerStyle.push(styles.alignNormal);
  } else if (align === 'stretch') {
    containerStyle.push(styles.alignStretch);
  } else {
    gradCardStyleArray.push(styles.alignCenter);
  }

  if (curved) {
    gradCardStyleArray.push(styles.curved);
  }

  if (flat) {
    gradCardStyleArray.push(styles.flat);
  }

  if (noDrop) {
    gradCardStyleArray.push(styles.noDrop);
  }

  if (expanded) {
    gradCardStyleArray.push(styles.expanded);
    containerStyle.push(styles.expanded);
  }

  if (overrideStyle) {
    gradCardStyleArray.push(overrideStyle);
  }

  if (overrideContainerStyle) {
    containerStyle.push(overrideContainerStyle);
  }
  return (
    <View testID="cardComponent" style={[colorArray, gradCardStyleArray]}>
      <TouchableOpacity
        testID={testID}
        onPress={onClick}
        disabled={disabled}
        style={[containerStyle]}
      >
        {children}
      </TouchableOpacity>
    </View>
  );
};

Card.defaultProps = defaultProps;

export default Card;
