import React, {useState} from 'react';
import {StyleSheet, ViewStyle} from 'react-native';
import {ComponentMeta, ComponentStory} from '@storybook/react';
import {storiesOf} from '@storybook/react-native';
import Flex from '../Flex/Flex';
import StoriesComponent from './Chip';
import Button from '../Button/Button';
import Text from '../Text/Text';
import InputText from '../InputText/InputText';
import SvgCirclePlus from '../icons/SvgCirclePlus';

type Styles = {
  type: ViewStyle;
  chipSpacing: ViewStyle;
};

const styles = StyleSheet.create<Styles>({
  type: {
    paddingHorizontal: 24,
    paddingVertical: 16,
  },
  chipSpacing: {
    marginBottom: 10,
  },
});

export const ChipWithIcons = () => {
  const [isOpen, setIsOpen] = useState(true);
  const [isOpen1, setIsOpen1] = useState(true);
  return (
    <>
      <Flex center>
        <Button
          onClick={() => {
            setIsOpen(true);
            setIsOpen1(true);
          }}
          type="secondary"
        >
          Show chips
        </Button>
      </Flex>
      <Flex overrideStyle={styles.type}>
        {isOpen && (
          <StoriesComponent
            message="Type something"
            type="info"
            onClose={() => {
              setIsOpen(false);
            }}
          />
        )}
      </Flex>
      <Flex overrideStyle={styles.type}>
        {isOpen1 && (
          <StoriesComponent
            message="Type something"
            type="success"
            onClose={() => {
              setIsOpen1(false);
            }}
            icon={(height, width, fill) => (
              <SvgCirclePlus height={height} width={width} fill={fill} />
            )}
          />
        )}
      </Flex>
    </>
  );
};

export const WithFlexWrapper = () => {
  const [isRow, setIsRow] = useState(false);
  return (
    <Flex>
      <Flex center>
        <Button
          onClick={() => {
            setIsRow(!isRow);
          }}
          type="secondary"
        >
          <Text color="theme">
            flexDirection:
            {isRow ? 'column' : 'row'}
          </Text>
        </Button>
      </Flex>
      <Flex between row={isRow}>
        <Flex overrideStyle={styles.chipSpacing}>
          <StoriesComponent
            message="Type something"
            icon={(height, width, fill) => (
              <SvgCirclePlus height={height} width={width} fill={fill} />
            )}
          />
        </Flex>
        <Flex overrideStyle={styles.chipSpacing}>
          <StoriesComponent message="Type something" />
        </Flex>
        <Flex start>
          <Button>Add Reason</Button>
        </Flex>
      </Flex>
    </Flex>
  );
};

export const WithPaddingMaintained = () => {
  const [val, setVal] = useState('20');
  const [message, setMessage] = useState('Maintain Padding');
  return (
    <Flex>
      <Flex between row>
        <Flex overrideStyle={styles.chipSpacing}>
          <Flex overrideStyle={{width: Number(val)}}>
            <StoriesComponent message={message} onClose={() => {}} />
          </Flex>
        </Flex>
        <Flex start row>
          <InputText value={val} onChange={setVal} label="Enter Width" />
          <InputText
            value={message}
            onChange={setMessage}
            label="Enter Message"
          />
        </Flex>
      </Flex>
    </Flex>
  );
};

export default {
  title: 'Components/Chip',
  component: StoriesComponent,
} as ComponentMeta<typeof StoriesComponent>;

const Template: ComponentStory<typeof StoriesComponent> = args => (
  <Flex>
    <StoriesComponent {...args} />
  </Flex>
);

export const Playground = Template.bind({});

Playground.args = {
  message: `Type something`,
};

if (typeof Window === 'undefined') {
  storiesOf('Chip', module)
    .add('Basic', () => <StoriesComponent message="Type something" />)
    .add('Chip with actions', () => <ChipWithIcons />)
    .add('With Flex Wrapper', () => <WithFlexWrapper />);
}
