import React, {useRef} from 'react';
import {StyleSheet, ViewStyle, View, TouchableOpacity} from 'react-native';
import {useHover} from 'react-native-web-hooks';
import Flex from '../Flex/Flex';
import Text from '../Text/Text';
import SvgClose from '../icons/SvgClose';
import {
  GRAY_20,
  SEMANTIC_INFO_BLUE_DARK,
  SEMANTIC_INFO_BLUE_TINT_2,
  SEMANTIC_SUCCESS_GREEN_DARK,
  SEMANTIC_SUCCESS_GREEN_TINT_2,
  SEMANTIC_WARNING_ORANGE_DARK,
  SEMANTIC_WARNING_ORANGE_TINT_2,
  LABEL_JUNGLE_GREEN_PRIMARY,
  LABEL_JUNGLE_GREEN_TINT_2,
  LABEL_KIWI_PRIMARY,
  LABEL_KIWI_TINT_2,
  LABEL_MAGENTA_PRIMARY,
  LABEL_MAGENTA_TINT_2,
  LABEL_PINK_PRIMARY,
  LABEL_PINK_TINT_2,
  LABEL_TURQUOISE_PRIMARY,
  LABEL_TURQUOISE_TINT_2,
  LABEL_VIOLET_PRIMARY,
  LABEL_VIOLET_TINT_2,
  LABEL_YELLOW_PRIMARY,
  LABEL_YELLOW_TINT_2,
  SEMANTIC_RED_TINT_2,
  SEMANTIC_RED_DARK,
} from '../UikitUtils/colors';

type Styles = {
  chip: ViewStyle;
  error: ViewStyle;
  info: ViewStyle;
  success: ViewStyle;
  warning: ViewStyle;
  jungleGreen: ViewStyle;
  kiwi: ViewStyle;
  magenta: ViewStyle;
  pink: ViewStyle;
  turquoise: ViewStyle;
  violet: ViewStyle;
  yellow: ViewStyle;
  closeIcon: ViewStyle;
  closeIconHover: ViewStyle;
  icon: ViewStyle;
  borderOnHover: ViewStyle;
  borderOffHover: ViewStyle;
  noShowClose: ViewStyle;
};

const styles = StyleSheet.create<Styles>({
  chip: {
    borderRadius: 2,
    paddingVertical: 5.5,
    // height: 28,
    paddingRight: 12,
    alignSelf: 'flex-start',
  },
  borderOnHover: {
    borderLeftWidth: 4,
    paddingLeft: 8,
    paddingRight: 6,
  },
  borderOffHover: {
    borderLeftWidth: 2,
    paddingLeft: 10,
    paddingRight: 6,
  },
  noShowClose: {
    borderLeftWidth: 2,
    paddingLeft: 10,
    paddingRight: 12,
  },
  closeIcon: {
    marginLeft: 8,
  },
  closeIconHover: {
    paddingLeft: 8,
    opacity: 0.5,
  },
  error: {
    backgroundColor: SEMANTIC_RED_TINT_2,
    borderLeftColor: SEMANTIC_RED_DARK,
  },
  info: {
    backgroundColor: SEMANTIC_INFO_BLUE_TINT_2,
    borderLeftColor: SEMANTIC_INFO_BLUE_DARK,
  },
  success: {
    backgroundColor: SEMANTIC_SUCCESS_GREEN_TINT_2,
    borderLeftColor: SEMANTIC_SUCCESS_GREEN_DARK,
  },
  warning: {
    backgroundColor: SEMANTIC_WARNING_ORANGE_TINT_2,
    borderLeftColor: SEMANTIC_WARNING_ORANGE_DARK,
  },
  jungleGreen: {
    backgroundColor: LABEL_JUNGLE_GREEN_TINT_2,
    borderLeftColor: LABEL_JUNGLE_GREEN_PRIMARY,
  },
  kiwi: {
    backgroundColor: LABEL_KIWI_TINT_2,
    borderLeftColor: LABEL_KIWI_PRIMARY,
  },
  magenta: {
    backgroundColor: LABEL_MAGENTA_TINT_2,
    borderLeftColor: LABEL_MAGENTA_PRIMARY,
  },
  pink: {
    backgroundColor: LABEL_PINK_TINT_2,
    borderLeftColor: LABEL_PINK_PRIMARY,
  },
  turquoise: {
    backgroundColor: LABEL_TURQUOISE_TINT_2,
    borderLeftColor: LABEL_TURQUOISE_PRIMARY,
  },
  violet: {
    backgroundColor: LABEL_VIOLET_TINT_2,
    borderLeftColor: LABEL_VIOLET_PRIMARY,
  },
  yellow: {
    backgroundColor: LABEL_YELLOW_TINT_2,
    borderLeftColor: LABEL_YELLOW_PRIMARY,
  },
  icon: {
    paddingRight: 8,
  },
});

export type chipColor =
  | 'jungleGreen'
  | 'kiwi'
  | 'magenta'
  | 'pink'
  | 'turquoise'
  | 'violet'
  | 'yellow';

export type chipType = 'error' | 'info' | 'success' | 'warning' | chipColor;

type Props = {
  message: string;
  onClose?: Function;
  type?: chipType;
  color?: chipColor;
  icon?: (height: number, width: number, fill: string) => React.ReactNode;
};
const getIconColor = (type: chipType) => {
  let color = SEMANTIC_INFO_BLUE_DARK;
  if (type === 'error') {
    color = SEMANTIC_RED_DARK;
  } else if (type === 'success') {
    color = SEMANTIC_SUCCESS_GREEN_DARK;
  } else if (type === 'warning') {
    color = SEMANTIC_WARNING_ORANGE_DARK;
  }
  return color;
};
const Chip = ({message, type = 'success', onClose, color, icon}: Props) => {
  const ref = useRef(null);
  const isHovered = useHover(ref);
  const showClose = typeof onClose === 'function';
  const styleArray = [styles.chip];
  if (color) {
    styleArray.push(styles[color]);
  } else {
    styleArray.push(styles[type]);
  }

  if (isHovered && showClose) {
    styleArray.push(styles.borderOnHover);
  } else if (!showClose) {
    styleArray.push(styles.noShowClose);
  } else {
    styleArray.push(styles.borderOffHover);
  }

  if (message) {
    return (
      <View ref={ref}>
        <Flex row center overrideStyle={styleArray} testID="chipOnhover">
          {icon && (
            <Flex overrideStyle={styles.icon}>
              {icon(14, 14, getIconColor(type))}
            </Flex>
          )}
          <Text size={14}>{message}</Text>
          {showClose && (
            <TouchableOpacity
              testID="chipPress"
              onPress={() => onClose && onClose()}
            >
              {isHovered ? (
                <Flex middle center overrideStyle={styles.closeIconHover}>
                  <SvgClose width={18} height={18} fill={GRAY_20} />
                </Flex>
              ) : (
                <Flex middle center overrideStyle={styles.closeIcon}>
                  <SvgClose width={18} height={18} fill={GRAY_20} />
                </Flex>
              )}
            </TouchableOpacity>
          )}
        </Flex>
      </View>
    );
  }
  return <View testID="emptyView" />;
};

export default Chip;
