import React from 'react';
import {Alert, Linking, Platform, StyleSheet} from 'react-native';
import ImagePicker from 'react-native-image-crop-picker';
import Button from '../Button/Button';
import Card from '../Card/Card';
import Flex from '../Flex/Flex';
import Modal from '../Modal/Modal';
import Text from '../Text/Text';

const styles = StyleSheet.create({
  overAll: {
    paddingHorizontal: 24,
    paddingVertical: 30,
  },
  chooseBtn: {
    marginVertical: 20,
  },
  takeBtn: {
    marginTop: 30,
  },
  marginTop: {
    marginTop: 20,
  },
});

type Props = {
  close: () => void;
  open: boolean;
  onChange: (a: any) => void;
  includeBase64?: boolean;
};

const DocumentPicker = ({open, close, onChange, includeBase64}: Props) => {
  const handleTakePhoto = () => {
    ImagePicker.openCamera({
      width: 1200,
      height: 1200,
      cropping: true,
      includeBase64,
    })
      .then(image => {
        onChange(image);
        close();
      })
      .catch(() => {
        if (Platform.OS === 'ios') {
          Alert.alert(
            'Permission',
            'Device camera permission blocked. Enable the camera permission manually',
            [
              {
                text: 'Cancel',
                onPress: () => {},
              },
              {
                text: 'Enable',
                onPress: () => {
                  Linking.openSettings();
                },
              },
            ],
          );
        }
      });
  };

  const handleChooseGallery = () => {
    ImagePicker.openPicker({
      width: 1200,
      height: 1200,
      cropping: true,
      mediaType: 'photo',
      includeBase64,
    })
      .then(image => {
        onChange(image);
        close();
      })
      .catch(() => {
        if (Platform.OS === 'ios') {
          Alert.alert(
            'Permission',
            'Device photos permission blocked. Enable the photos permission manually',
            [
              {
                text: 'Cancel',
                onPress: () => {},
              },
              {
                text: 'Enable',
                onPress: () => {
                  Linking.openSettings();
                },
              },
            ],
          );
        }
      });
  };

  return (
    <Modal open={open} animationType='fade'>
      <Card align="stretch" overrideStyle={styles.overAll}>
        <Flex>
          <Text align="center" size={18} bold>
            Upload Photo
          </Text>
          <Text align="center" color="gray" overrideStyle={styles.marginTop}>
            Choose Your Profile Picture
          </Text>
          <Button overrideStyle={styles.takeBtn} onClick={handleTakePhoto}>
            Take Photo
          </Button>
          <Button
            overrideStyle={styles.chooseBtn}
            onClick={handleChooseGallery}
          >
            Choose From Gallery
          </Button>
          <Button onClick={close} type="secondary">
            Cancel
          </Button>
        </Flex>
      </Card>
    </Modal>
  );
};

export default DocumentPicker;
