import {ComponentStory, ComponentMeta} from '@storybook/react';
import {storiesOf} from '@storybook/react-native';
import React, {useState} from 'react';
import Button from '../Button/Button';
import Flex from '../Flex/Flex';
import InputText from '../InputText/InputText';
import StoriesComponent from './ErrorMessage';

export default {
  title: `Components/ErrorMessage`,
  component: StoriesComponent,
} as ComponentMeta<typeof StoriesComponent>;

const Template: ComponentStory<typeof StoriesComponent> = args => {
  const [value, setValue] = useState('');
  const [touched, setTouched] = useState(false);

  const {errors} = args;
  const errorKey = Object.keys(errors)[0];
  const label = errorKey.charAt(0).toUpperCase() + errorKey.slice(1);

  return (
    <Flex between>
      <Flex>
        <Button onClick={() => setTouched(!touched)} type="tertiary">
          Set Error
        </Button>
      </Flex>
      <Flex>
        <InputText label={label} value={value} onChange={setValue} />
        <StoriesComponent {...args} touched={{[errorKey]: touched && !value}} />
      </Flex>
    </Flex>
  );
};

export const Playground = Template.bind({});

Playground.args = {
  errors: {name: 'Please enter any name!!'},
  name: 'name',
  touched: {name: false},
};

if (typeof Window === 'undefined') {
  storiesOf('Error Message', module).add('Playground', () => (
    <Playground
      name="name"
      errors={{name: 'Please enter any name!!'}}
      touched={{name: false}}
    />
  ));
}
