import React, {useEffect, useRef, useCallback, useContext} from 'react';
import {Animated, Easing, TouchableOpacity, StyleSheet} from 'react-native';
import Flex from '../Flex/Flex';
import Text, {textColors} from '../Text/Text';
import SvgRadioWithLine from '../icons/SvgRadioWithLine';
import SvgRadioWithOutOutLine from '../icons/SvgRadioWithOutOutLine';
import ThemeContext from '../ThemeContext/ThemeContext';
import {isEmpty} from '../UikitUtils/validators';
import {primaryColor} from '../UikitUtils/themeHelper';

const styles = StyleSheet.create({
  text: {
    marginLeft: 12,
  },
});

type DefaultPropsTypes = {
  name?: string;
};

const defaultProps: DefaultPropsTypes = {
  name: '',
};

type Props = {
  onClick?: (args: any) => void;
  onBlur?: (args: any) => void;
  checked?: boolean;
  color?: string;
  size?: number;
  label?: import('react').ReactNode;
  value?: string;
  labelColor?: textColors;
  labelSize?: number;
  disabled?: boolean;
} & typeof defaultProps;

const InputRadio = ({
  onClick,
  onBlur,
  name,
  checked,
  size,
  color,
  label,
  labelSize,
  labelColor,
  value,
  disabled,
}: Props) => {
  const {theme} = useContext(ThemeContext);
  const currentValue = useRef(new Animated.Value(0)).current;
  const handleOnClick = useCallback(
    (e: any) => {
      if (typeof onClick === 'function' && e && !disabled) {
        const requiredVal = typeof value !== 'undefined' ? value : name;
        e.target.value = requiredVal;
        onClick(e);
      }
    },
    [onClick],
  );

  useEffect(() => {
    if (checked === true) {
      Animated.timing(currentValue, {
        toValue: 0.8,
        duration: 20,
        easing: Easing.in(Easing.bounce),
        useNativeDriver: false,
      }).start(() => {
        Animated.spring(currentValue, {
          toValue: 1,
          useNativeDriver: false,
        }).start();
      });
    }
  }, [checked]);

  let colors;
  if (isEmpty(color)) {
    colors = primaryColor(theme);
  } else {
    colors = color;
  }
  return (
    <TouchableOpacity
      testID="InputRadio"
      onPress={handleOnClick}
      onBlur={onBlur}
      activeOpacity={1}
    >
      <Flex row center>
        {checked ? (
          <Animated.View style={{transform: [{scale: currentValue}]}}>
            <SvgRadioWithLine height={size} width={size} fill={colors} />
          </Animated.View>
        ) : (
          <SvgRadioWithOutOutLine height={size} width={size} />
        )}
        <Text
          testID="label"
          size={labelSize}
          color={labelColor}
          overrideStyle={styles.text}
        >
          {label}
        </Text>
      </Flex>
    </TouchableOpacity>
  );
};

InputRadio.defaultProps = {
  labelSize: 14,
};

export default InputRadio;
