import React, {useState} from 'react';
import {ScrollView} from 'react-native';
import {action} from '@storybook/addon-actions';
import SvgDownAngle from '../icons/SvgDownAngle';
import Button from '../Button/Button';
import Flex from '../Flex/Flex';
import {InputTextComponent} from '../UikitUtils/storiesHelper';
import StoriesComponent from './InputText';
import {ComponentStory} from '@storybook/react';

const multiLineValue = `Storybook extracts the component's description and renders it at the top of the page. It is automatically generated from the docgen component for the supported frameworks based on the component's source code. Below is an abridged example and available options.`;

export const Basic = () => {
  const [value, setValue] = useState('');
  const [error, setError] = useState(false);
  const handleChange = (val: string) => {
    action('change')(val);
    setValue(val);
  };
  return (
    <ScrollView>
      <Flex
        overrideStyle={{
          paddingHorizontal: '20%',
          paddingTop: 30,
          paddingBottom: 40,
        }}
      >
        <Button
          onClick={() => setError(!error)}
          overrideStyle={{marginVertical: 24}}
        >
          Set Error
        </Button>
        <InputTextComponent label="Input AutoFocus">
          <StoriesComponent
            autoFocus
            type="curved"
            placeholder="Input autoFocus"
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input Error">
          <StoriesComponent
            label="Input Error"
            required
            value={value}
            onChange={handleChange}
            error={error}
            placeholder="Error"
          />
        </InputTextComponent>
        <InputTextComponent label="Input Normal">
          <StoriesComponent
            error={error}
            type="normal"
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input Normal Disabled">
          <StoriesComponent
            error={error}
            type="normal"
            value={value}
            onChange={handleChange}
            disabled
          />
        </InputTextComponent>

        <InputTextComponent label="Input curved ">
          <StoriesComponent
            placeholder="curved"
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input curved disabled">
          <StoriesComponent
            disabled
            placeholder="curved"
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>

        <InputTextComponent label="Input rounded">
          <StoriesComponent
            type="rounded"
            placeholder="rounded"
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input rounded disabled">
          <StoriesComponent
            disabled
            type="rounded"
            placeholder="rounded"
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>

        <InputTextComponent label="Input noBorder ">
          <StoriesComponent
            type="noBorder"
            placeholder="noBorder"
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input noBorder disabled">
          <StoriesComponent
            disabled
            type="noBorder"
            placeholder="noBorder"
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>

        <InputTextComponent label="Input align center ">
          <StoriesComponent
            align="center"
            placeholder="align center"
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input align left ">
          <StoriesComponent
            align="left"
            placeholder="align left"
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input align right ">
          <StoriesComponent
            align="right"
            placeholder="align right"
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input align top ">
          <StoriesComponent
            align="top"
            placeholder="align top"
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input disabled">
          <StoriesComponent
            disabled
            placeholder="disabled"
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input text bold">
          <StoriesComponent
            bold
            placeholder="text bold"
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input label required">
          <StoriesComponent
            required
            label="label text required"
            placeholder="label text required            "
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input curved action">
          <StoriesComponent
            placeholder="action"
            actionRight={() => <SvgDownAngle />}
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input curved actionLeft">
          <StoriesComponent
            placeholder="actionLeft"
            actionLeft={() => <SvgDownAngle />}
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input normal action">
          <StoriesComponent
            type="normal"
            placeholder="action"
            actionRight={() => <SvgDownAngle />}
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input normal actionLeft">
          <StoriesComponent
            type="normal"
            placeholder="actionLeft"
            actionLeft={() => <SvgDownAngle />}
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input rounded action">
          <StoriesComponent
            type="rounded"
            placeholder="action"
            actionRight={() => <SvgDownAngle />}
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input rounded actionLeft">
          <StoriesComponent
            type="rounded"
            placeholder="actionLeft"
            actionLeft={() => <SvgDownAngle />}
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>

        <InputTextComponent label="Input normal action">
          <StoriesComponent
            type="normal"
            actionRight={() => <SvgDownAngle />}
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input normal actionLeft">
          <StoriesComponent
            type="normal"
            actionLeft={() => <SvgDownAngle />}
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input onClear">
          <StoriesComponent
            onClear
            placeholder="onClear"
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input size">
          <StoriesComponent
            size={20}
            placeholder="input size"
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input text color theme">
          <StoriesComponent
            color="theme"
            placeholder="Input text theme color"
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input text color black">
          <StoriesComponent
            color="black"
            placeholder="Input text black color"
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input text color error">
          <StoriesComponent
            color="error"
            placeholder="Input text error color"
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input text color gray">
          <StoriesComponent
            color="gray"
            placeholder="Input text gray color"
            value={value}
            onChange={handleChange}
          />
        </InputTextComponent>
        <InputTextComponent label="Input multiline">
          <StoriesComponent
            multiline
            placeholder="Input multiline"
            numberOfLines={10}
            value={multiLineValue}
            onChange={action('multiline')}
          />
        </InputTextComponent>
        <InputTextComponent label="Input noraml multiline">
          <StoriesComponent
            align="top"
            multiline
            type="normal"
            placeholder="Input noraml multiline"
            numberOfLines={10}
            value={multiLineValue}
            onChange={action('multiline')}
          />
        </InputTextComponent>
      </Flex>
    </ScrollView>
  );
};

const Template: ComponentStory<typeof StoriesComponent> = args => (
  <StoriesComponent {...args} />
);

export const Playground = Template.bind({});

export default {
  title: 'Components/InputText',
  component: StoriesComponent,
};
