import {TextStyle, ViewStyle} from 'react-native';
import {styles as textStyles} from '../Text/textStyle';
import {GRAY_50} from '../UikitUtils/colors';
import {ThemeType} from '../UikitUtils/themeTypes';
import {styles} from './InputStyle';
import {InputAlign, InputTypes, isInputTextTypeKey} from './InputText';

type inputTypeProps = {
  theme: ThemeType;
  containerStyleArray: ViewStyle[];
  type: InputTypes;
};

export const inputTypesHelper = ({
  type,
  containerStyleArray,
}: inputTypeProps) => {
  if (isInputTextTypeKey(type)) {
    switch (type) {
      case 'normal':
        containerStyleArray.push(styles.normal);
        break;
      case 'curved':
        containerStyleArray.push(styles.curved);
        break;
      case 'rounded':
        containerStyleArray.push(styles.rounded);
        break;
      case 'noBorder':
        containerStyleArray.push(styles.noBorder);
        break;
      default:
        containerStyleArray.push(styles.curved);
        break;
    }
  }
};

type inputActionProps = {
  actionLeftStyleArray: ViewStyle[];
  actionRightStyleArray: ViewStyle[];
  type: InputTypes;
  theme: ThemeType;
};

export const inputActionHelper = ({
  actionLeftStyleArray,
  actionRightStyleArray,
  type,
  theme,
}: inputActionProps) => {
  switch (type) {
    case 'normal':
      actionLeftStyleArray.push(styles.leftAction);
      actionRightStyleArray.push(styles.rightAction);
      break;
    default:
      if (theme !== 'drug') {
        actionLeftStyleArray.push(styles.actionLeft);
      }
      actionRightStyleArray.push(styles.action);
      break;
  }
};

export const inputAlginHelper = (
  align: InputAlign,
  textStyleArray: ViewStyle[] | TextStyle[],
) => {
  switch (align) {
    case 'center':
      textStyleArray.push(textStyles.center);
      break;
    case 'right':
      textStyleArray.push(textStyles.right);
      break;
    case 'top':
      textStyleArray.push(styles.textAlignVertical);
      break;
    default:
      textStyleArray.push(textStyles.left);
      break;
  }
};

type inputHelperType = {
  theme: ThemeType;
  containerStyleArray: ViewStyle[];
  flex: number | undefined;
  error: boolean | undefined;
  overrideStyle: ViewStyle | undefined | any;
  disabled: boolean | undefined;
  white: boolean | undefined;
};

export const inputHelper = ({
  containerStyleArray,
  flex,
  error,
  overrideStyle,
  disabled,
  white,
}: inputHelperType) => {
  if (flex) {
    containerStyleArray.push({flex});
  }
  if (error && !disabled) {
    containerStyleArray.push(styles.error);
  }
  if (disabled) {
    containerStyleArray.push(styles.disabled);
  }
  if (overrideStyle) {
    containerStyleArray.push(overrideStyle);
  }
  if (white) {
    containerStyleArray.push(styles.white);
  }
};

type textStyleHelperProps = {
  theme: ThemeType;
  actionRight: Function | undefined;
  actionLeft: Function | undefined;
  textStyleArray: ViewStyle[] | TextStyle[];
  bold: boolean | undefined;
  size: number;
  disabled?: boolean;
  type: InputTypes;
};

export const textStyleHelper = ({
  actionRight,
  actionLeft,
  textStyleArray,
  bold,
  size,
  disabled,
  type,
}: textStyleHelperProps) => {
  if (typeof actionRight === 'function') {
    textStyleArray.push(styles.inputAction);
  }
  if (typeof actionLeft === 'function') {
    textStyleArray.push(styles.inputAction);
  }
  if (bold) {
    textStyleArray.push(textStyles.bold);
  }
  if (disabled) {
    textStyleArray.push({color: GRAY_50});
  }
  if (size) {
    textStyleArray.push({fontSize: size});
  }
  if (type === 'normal') {
    textStyleArray.push(styles.normalCommon);
  } else {
    textStyleArray.push(styles.common);
  }
};

export const minHeights = (
  minHeight: number | undefined,
  styleArray: ViewStyle[],
) => {
  if (typeof minHeight === 'number') {
    styleArray.push({minHeight: minHeight});
  }
};
