import React, {memo, useState, useEffect} from 'react';
import {View, StyleSheet, ViewStyle} from 'react-native';
import Text, {textColors} from '../Text/Text';
import {isEmpty} from '../UikitUtils/validators';

// import
type Props = {
  required?: boolean;
  children?: import('react').ReactNode;
  label?: string;
  labelSize?: number;
  labelColor?: textColors;
  error?: boolean;
};

const styles = StyleSheet.create({
  labelContainer: {
    flexDirection: 'row',
  },
  required: {
    marginLeft: 4,
  },
  labelStyle: {
    marginBottom: 8,
  },
  labelStyleOne: {
    marginBottom: 0,
  },
});
const LabelWrapper = ({
  required,
  children,
  label,
  labelSize,
  labelColor,
  error,
}: Props) => {
  const [style, setStyle] = useState<ViewStyle[]>();

  useEffect(() => {
    const styleArray: ViewStyle[] = [styles.labelContainer];
    if (isEmpty(label)) {
      styleArray.push(styles.labelStyleOne);
    } else {
      styleArray.push(styles.labelStyle);
    }
    setStyle(styleArray);
  }, [label]);

  const errorLabel = error ? 'error' : labelColor;
  const errorRequired=error ? 'error':'theme'
  return !isEmpty(label) ? (
    <View>
      <View style={style}>
        <Text size={labelSize} color={errorLabel}>
          {label}
        </Text>
        {required && (
          <Text
            size={labelSize}
            color={errorRequired}
            overrideStyle={styles.required}
          >
            *
          </Text>
        )}
      </View>
      {children}
    </View>
  ) : (
    <>{children}</>
  );
};

export default memo(
  LabelWrapper,
  (prevProps: Props, nextProps: Props) =>
    prevProps.children === nextProps.children,
);
