import React, {useContext} from 'react';
import {
  ActivityIndicator,
  Dimensions,
  Modal,
  SafeAreaView,
  StyleSheet,
  ViewStyle,
} from 'react-native';
import ThemeContext from '../ThemeContext/ThemeContext';
import { primaryColor } from '../UikitUtils/themeHelper';

const {height} = Dimensions.get('window');

type Styles = {
  container: ViewStyle;
  loader: ViewStyle;
};

const styles = StyleSheet.create<Styles>({
  container: {
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: 'rgba(0,0,0,0.25)',
    height: height,
  },
  loader: {
    opacity: 1,
  },
});

const Loader = () => {
  const {theme} = useContext(ThemeContext);

  return (
    <Modal animationType="none" transparent={true} visible={true}>
      <SafeAreaView style={styles.container}>
        <ActivityIndicator
          size="large"
          style={styles.loader}
          color={primaryColor(theme)}
        />
      </SafeAreaView>
    </Modal>
  );
};

export default Loader;
