import React, {useState} from 'react';
import {ComponentMeta, ComponentStory} from '@storybook/react';
import {storiesOf} from '@storybook/react-native';
import StoriesComponent from './Modal';
import Flex from '../Flex/Flex';
import Text from '../Text/Text';
import {BLACK} from '../UikitUtils/colors';
import Button from '../Button/Button';
import SvgCalendar from '../icons/SvgCalendar';

const TWO_BUTTONS = 'twoButtons';
const WITH_CLOSE_ICON = 'withCloseIcon';
const WITH_TITTLE_ICON = 'withTittleIcon';
const WITH_LARGE_ICON = 'withLargeIcon';
const WITH_TITTLE_AND_CLOSE_ICON = 'withTittleAndCloseIcon';
const WITH_LOADING = 'withLoading';

export const Basic = () => {
  const [modalType, setShowModalType] = useState('');
  const [loading, setLoading] = useState(false);
  const confirmTitle = 'Are you sure?';
  const message =
    'The Modal component is a basic way to present content above an enclosing view.';
  const confirmPrimaryAction = 'Confirm';
  const confirmSecondaryAction = 'Cancel';
  const closeModalHandler = () => setShowModalType('');
  const loadingAction = 'Load for 3s';
  const loaderHandler = () => {
    setLoading(true);
    setTimeout(() => {
      setLoading(false);
    }, 3000);
  };
  return (
    <>
      <Flex overrideStyle={{padding: 20}}>
        <Button
          onClick={() => setShowModalType(TWO_BUTTONS)}
          overrideStyle={{marginBottom: 20}}
        >
          Modal with Primary and Secondary Button
        </Button>
        <StoriesComponent
          key={TWO_BUTTONS}
          open={modalType === TWO_BUTTONS}
          title={confirmTitle}
          primaryAction={confirmPrimaryAction}
          primaryActionHandler={closeModalHandler}
          secondaryAction={confirmSecondaryAction}
          secondaryActionHandler={closeModalHandler}
        >
          <Text size={18}>{message}</Text>
        </StoriesComponent>

        <Button
          onClick={() => setShowModalType(WITH_CLOSE_ICON)}
          overrideStyle={{marginBottom: 20}}
        >
          Modal with close icon
        </Button>
        <StoriesComponent
          key={WITH_CLOSE_ICON}
          showClose
          open={modalType === WITH_CLOSE_ICON}
          onClose={closeModalHandler}
          title={confirmTitle}
          primaryAction={confirmPrimaryAction}
          primaryActionHandler={closeModalHandler}
          secondaryAction={confirmSecondaryAction}
          secondaryActionHandler={closeModalHandler}
        >
          <Text size={18}>{message}</Text>
        </StoriesComponent>

        <Button
          onClick={() => setShowModalType(WITH_TITTLE_ICON)}
          overrideStyle={{marginBottom: 20}}
        >
          Modal with Tittle icon
        </Button>
        <StoriesComponent
          key={WITH_TITTLE_ICON}
          showIcon={(height, width) => (
            <SvgCalendar fill={BLACK} height={height} width={width} />
          )}
          open={modalType === WITH_TITTLE_ICON}
          onClose={closeModalHandler}
          title={confirmTitle}
          primaryAction={confirmPrimaryAction}
          primaryActionHandler={closeModalHandler}
          secondaryAction={confirmSecondaryAction}
          secondaryActionHandler={closeModalHandler}
        >
          <Text size={18}>{message}</Text>
        </StoriesComponent>
        <Button
          onClick={() => setShowModalType(WITH_TITTLE_AND_CLOSE_ICON)}
          overrideStyle={{marginBottom: 20}}
        >
          Modal with Tittle icon and Close icon
        </Button>
        <StoriesComponent
          key={WITH_TITTLE_AND_CLOSE_ICON}
          showClose
          showIcon={(height, width) => (
            <SvgCalendar fill={BLACK} height={height} width={width} />
          )}
          open={modalType === WITH_TITTLE_AND_CLOSE_ICON}
          onClose={closeModalHandler}
          title={confirmTitle}
          primaryAction={confirmPrimaryAction}
          primaryActionHandler={closeModalHandler}
          secondaryAction={confirmSecondaryAction}
          secondaryActionHandler={closeModalHandler}
        >
          <Text size={18}>{message}</Text>
        </StoriesComponent>
        <Button
          onClick={() => setShowModalType(WITH_LARGE_ICON)}
          overrideStyle={{marginBottom: 20}}
        >
          Modal with Large icon
        </Button>
        <StoriesComponent
          key={WITH_LARGE_ICON}
          iconSize="large"
          showIcon={(height, width) => (
            <SvgCalendar fill={BLACK} height={height} width={width} />
          )}
          open={modalType === WITH_LARGE_ICON}
          onClose={closeModalHandler}
          title={confirmTitle}
          primaryAction={confirmPrimaryAction}
          primaryActionHandler={closeModalHandler}
          secondaryAction={confirmSecondaryAction}
          secondaryActionHandler={closeModalHandler}
        >
          <Text size={18} align="center">
            {message}
          </Text>
        </StoriesComponent>
        <Button
          onClick={() => setShowModalType(WITH_LOADING)}
          overrideStyle={{marginBottom: 20}}
        >
          Modal with Primary Action Loading
        </Button>
        <StoriesComponent
          key={WITH_LOADING}
          open={modalType === WITH_LOADING}
          title={confirmTitle}
          primaryAction={loadingAction}
          primaryActionHandler={loaderHandler}
          secondaryAction={confirmSecondaryAction}
          secondaryActionHandler={closeModalHandler}
          onClose={closeModalHandler}
          isLoading={loading}
        >
          <Text size={18} align="center">
            {message}
          </Text>
        </StoriesComponent>
      </Flex>
    </>
  );
};

if (typeof Window === 'undefined') {
  storiesOf('Modal', module).add('Modal', () => <Basic />);
}

export default {
  title: 'Components/Modal',
  component: StoriesComponent,
} as ComponentMeta<typeof StoriesComponent>;

const Template: ComponentStory<typeof StoriesComponent> = args => (
  <StoriesComponent {...args} />
);

export const Playground = Template.bind({});

Playground.args = {};
