import React, {ReactNode} from 'react';
import {StyleSheet} from 'react-native';
import Flex from '../Flex/Flex';
import Text from '../Text/Text';

const uikitStyles = StyleSheet.create({
  titlePadding: {
    paddingVertical: 5,
  },
});

type Props = {
  title?: string;
  showIcon?: (height: number, width: number) => ReactNode;
  iconSize?: 'normal' | 'large';
};

const ModalIcon = ({title, showIcon, iconSize}: Props) => {
  const iconDimentions =
    iconSize === 'large' ? {height: 54, width: 54} : {height: 34, width: 34};
  return (
    <Flex row={showIcon && iconSize !== 'large'} center>
      {showIcon && (
        <Flex
          column
          row={iconSize === 'large'}
          overrideStyle={{
            paddingRight: iconSize !== 'large' ? 16 : 0,
            paddingBottom: iconSize === 'large' ? 35 : 0,
          }}
          middle={iconSize === 'large'}
        >
          {showIcon(iconDimentions.height, iconDimentions.width)}
        </Flex>
      )}
      {iconSize === 'large' ? (
        <Flex column row middle>
          <Text bold size={24} align="center" color="black">
            {title}
          </Text>
        </Flex>
      ) : (
        <Flex column>
          <Text
            bold
            size={24}
            color="black"
            overrideStyle={uikitStyles.titlePadding}
          >
            {title}
          </Text>
        </Flex>
      )}
    </Flex>
  );
};
export default ModalIcon;
