import React, { useMemo, memo } from 'react';
import { StyleSheet } from 'react-native';
import Text from '../Text/Text';
import { removeUnderScores } from '../UikitUtils/helpers';
import { isEmpty } from '../UikitUtils/validators';

const styles = StyleSheet.create({
  inputText: {
    flex: 1,
    paddingHorizontal: 16,
    paddingVertical: 12,
    minHeight: 40,
  },
});

type Props = {
  displayValue: string;
  placeholder?: string;
};
const RenderMultiSelectInput = ({ displayValue, placeholder }: Props) => {
  const memoizedValue = useMemo(
    () => removeUnderScores(displayValue),
    [displayValue],
  );
  const value = isEmpty(memoizedValue) ? placeholder : memoizedValue;
  const color = isEmpty(memoizedValue) ? 'gray' : 'primary';
  return (
    <Text
      size={14}
      color={color}
      overrideStyle={styles.inputText}
      ellipsizeMode="tail"
      numberOfLines={1}
    >
      {value}
    </Text>
  );
};
export default memo(RenderMultiSelectInput);
