import React, { useMemo, memo } from 'react';
import { StyleSheet, TouchableOpacity } from 'react-native';
import Text from '../Text/Text';
import { removeUnderScores } from '../UikitUtils/helpers';
import { list } from '../SelectTag/SelectRowList';
import { MultiOptionsEntity } from './SelectTag.types';
import CheckBox from '../CheckBox/CheckBox';

const styles = StyleSheet.create({
  selectItem: {
    flexDirection: 'row',
    alignItems: 'center',
    paddingHorizontal: 12,
    paddingBottom: 16,
  },
  selectItemOne: {
    flexDirection: 'row',
    alignItems: 'center',
    paddingHorizontal: 12,
    paddingVertical: 16,
  },
  labelText: {
    marginLeft: 8,
  },
});

type Props = {
  selectOptions: MultiOptionsEntity[];
  option: list;
  stringifyLabelKey: string;
  handleOnSelect: (val: string) => void;
  stringifyValueKey: string;
  index?: number;
};
const RenderMultiSelectOption = ({
  selectOptions,
  option,
  stringifyLabelKey,
  handleOnSelect,
  stringifyValueKey,
  index,
}: Props) => {
  const opt = selectOptions[0].label === option[stringifyLabelKey];
  const style = opt || index === 0 ? styles.selectItemOne : styles.selectItem;
  const memoizedLabel = useMemo(
    () => removeUnderScores(option[stringifyLabelKey]),
    [option],
  );
  return (
    <TouchableOpacity
      testID="handleOnSelectId"
      onPress={() => handleOnSelect(option[stringifyValueKey])}
      style={style}
    >
      <CheckBox
        testID="multiSelectCheckBox"
        onClick={() => handleOnSelect(option[stringifyValueKey])}
        checked={option.isChecked}
      />
      <Text overrideStyle={styles.labelText}>Check {memoizedLabel}</Text>
    </TouchableOpacity>
  );
};
export default memo(RenderMultiSelectOption);
