import React, { useEffect, useState } from 'react';
import { StyleSheet, TextStyle, ViewStyle } from 'react-native';
import Flex from '../Flex/Flex';
import Text from '../Text/Text';
import { list } from './SelectRowList';

type Props = {
  item: list;
  searchOption: string;
  index: number;
  size?: number;
  bold?: boolean;
  overrideStyleOptionsItem?: TextStyle;
  searchListTestId?: string;
};

const styles = StyleSheet.create({
  optionArray: {
    paddingHorizontal: 16,
  },
  paddingBottom: {
    paddingBottom: 16,
  },
  paddingBottomOne: {
    paddingBottom: 0,
  },
  textStyle: {
    marginTop: 4,
  },
});

const SearchListLabel = ({
  item,
  searchOption,
  index,
  size,
  bold,
  overrideStyleOptionsItem,
  searchListTestId,
}: Props) => {
  const [styleFlex, setStyleFlex] = useState<ViewStyle[]>([]);

  const requiredLabel = item[searchOption];
  const rowColor = index > 0 ? 'gray' : 'primary';

  useEffect(() => {
    const styleFlexContainer: ViewStyle[] = [styles.optionArray];
    if (index > 0) {
      styleFlexContainer.push(styles.paddingBottom);
    } else {
      styleFlexContainer.push(styles.paddingBottomOne);
    }
    setStyleFlex(styleFlexContainer);
  }, [index]);

  return (
    <Flex
      testID="selectInnerRowList"
      overrideStyle={StyleSheet.flatten(styleFlex)}
    >
      <Text
        testID={searchListTestId}
        transform="capitalize"
        size={size}
        color={rowColor}
        bold={bold}
        overrideStyle={StyleSheet.flatten([
          overrideStyleOptionsItem,
          styles.textStyle,
        ])}
      >
        {requiredLabel}
      </Text>
    </Flex>
  );
};

export default SearchListLabel;
