import React, { memo, useRef, useEffect } from 'react';

import { Animated, Platform } from 'react-native';

type Props = {
  isOpen: boolean;
  children: import('react').ReactChild;
};
const nativeDriverPlatform = Platform.OS === 'web';

const SelectListAnimation = ({ isOpen, children }: Props) => {
  const animationValue = useRef(new Animated.ValueXY({ x: 0, y: 0 })).current;

  useEffect(() => {
    if (isOpen) {
      Animated.timing(animationValue, {
        toValue: { x: 0, y: 40 },
        duration: 300,
        useNativeDriver: nativeDriverPlatform,
      }).start();
    }
    if (!isOpen) {
      Animated.timing(animationValue, {
        toValue: { x: 0, y: 0 },
        duration: 300,
        useNativeDriver: nativeDriverPlatform,
      }).start();
    }
  }, [isOpen]);

  return (
    <Animated.View style={animationValue.getLayout()}>{children}</Animated.View>
  );
};

export default memo(
  SelectListAnimation,
  (prevProps: Props, nextProps: Props) =>
    prevProps.children === nextProps.children,
);
