/* eslint global-require: "off" */
import React, { ReactNode } from 'react';
import {
  GestureResponderEvent,
  StyleSheet,
  TextStyle,
  TouchableOpacity,
  View,
} from 'react-native';
import Flex from '../Flex/Flex';
import Text from '../Text/Text';
import RenderMultiSelectOption from './RenderMultiSelectOption';
import SearchListLabel from './SearchListLabel';
import { defaultProps } from './SelectList';

export type list = {
  [key: string]: any;
};

type Props = {
  onChange: Function;
  handleClose: Function;
  renderOption?: (a: list) => ReactNode;
  item: list;
  overrideStyleOptionsItem?: TextStyle;
  searchBy?: string[];
  multiselect?: boolean;
  handleOnSelect?: (arg: string) => void;
  searchListTestId?: string;
  index: number;
} & typeof defaultProps;

const styles = StyleSheet.create({
  options: {
    paddingHorizontal: 16,
    paddingTop: 16,
    paddingBottom: 16,
  },

  optionArray: {
    paddingHorizontal: 16,
    paddingVertical: 4,
  },
});

const SelectRowList = ({
  labelKey,
  onChange,
  handleClose,
  size,
  color,
  bold,
  renderOption,
  valueKey,
  item,
  overrideStyleOptionsItem,
  searchBy,
  multiselect,
  handleOnSelect,
  options,
  searchListTestId,
  index,
}: Props) => {
  const value = item[valueKey] || '';
  const label = item[labelKey] || '';
  const stringifyLabelKey = `${labelKey}`;
  const stringifyValueKey = `${valueKey}`;
  const handleSelectItem = (e: GestureResponderEvent) => {
    if (e) {
      e.stopPropagation();
      e.preventDefault();
    }
    if (!multiselect) {
      onChange(value, item);
    }
    handleClose();
  };

  const handleSelectFn = (val: string) => {
    if (typeof handleOnSelect === 'function') {
      handleOnSelect(val);
    }
  };

  return (
    <TouchableOpacity
      onPress={handleSelectItem}
      key={value}
      testID="selectrowlist"
    >
      {Array.isArray(searchBy) && (
        <View>
          {searchBy.map((searchOption, ind) => (
            <SearchListLabel
              searchListTestId={searchListTestId}
              item={item}
              searchOption={searchOption}
              index={ind}
              size={size}
              bold={bold}
              overrideStyleOptionsItem={overrideStyleOptionsItem}
            />
          ))}
        </View>
      )}
      {(() => {
        let rowResult: ReactNode;
        switch (multiselect) {
          case true:
            rowResult = (
              <RenderMultiSelectOption
                selectOptions={options}
                option={item}
                stringifyLabelKey={stringifyLabelKey}
                handleOnSelect={(val) => handleSelectFn(val)}
                stringifyValueKey={stringifyValueKey}
                index={index}
              />
            );
            break;
          case undefined:
          case false:
            if (typeof renderOption === 'function') {
              rowResult = renderOption(item);
            }
            if (
              typeof renderOption !== 'function' &&
              !Array.isArray(searchBy)
            ) {
              rowResult = (
                <Flex overrideStyle={styles.options}>
                  <Text
                    size={size}
                    color={color}
                    bold={bold}
                    overrideStyle={overrideStyleOptionsItem}
                  >
                    {label}
                  </Text>
                </Flex>
              );
            }
            break;
        }
        return rowResult;
      })()}
    </TouchableOpacity>
  );
};

SelectRowList.defaultProps = defaultProps;

export default SelectRowList;
