import React, {useState} from 'react';
import {action} from '@storybook/addon-actions';
import {StyleSheet} from 'react-native';
import {DROPDOWN_DATA} from './SelectMock';
import StoriesComponent from './SelectTag';
import Text from '../Text/Text';
import Flex from '../Flex/Flex';
import {GRAY_90} from '../UikitUtils/colors';
import {ComponentStory} from '@storybook/react';

const uikitStyles = StyleSheet.create({
  renderOptionStyles: {
    margin: 1,
    borderBottomWidth: 2,
    borderColor: GRAY_90,
    padding: 2,
  },
});

const storyText = 'Select tag clicked';
const withMultiSelectLabel = 'SelectTag with Multi-Select';
const withMultiSelectPalceholder = 'Can select multiple options';
const withSearchLabel = 'SelectTag with Search';
const withSearchPlaceholder = "Can 'Search' through the options";
const disabledLabel = 'Disabled SelectTag';
const disabledPlaceholder = 'Disabled';
const withRenderOptionLabel = 'SelectTag with custom renderOption';
const withRenderOtionPlaceholder = 'Select any option..';

const commonArgs = {
  onChange: () => '',
  labelKey: 'label',
  valueKey: 'id',
  placeholder: 'Select Tag',
  options: DROPDOWN_DATA,
};

const Template: ComponentStory<typeof StoriesComponent> = args => {
  const [value, setValue] = useState('');
  const changeHandler = (val: string) => {
    setValue(val);
    action(storyText)(val);
  };
  return <StoriesComponent {...args} onChange={changeHandler} value={value} />;
};

export const Playground = Template.bind({});

Playground.args = {
  ...commonArgs,
  label: 'Playground SelectTag',
};

export const WithSearch = Template.bind({});

WithSearch.args = {
  ...commonArgs,
  label: withSearchLabel,
  placeholder: withSearchPlaceholder,
  search: true,
};

export const WithMultiselect = Template.bind({});

WithMultiselect.args = {
  ...commonArgs,
  label: withMultiSelectLabel,
  placeholder: withMultiSelectPalceholder,
  multiselect: true,
};

export const WithRenderOption = Template.bind({});

WithRenderOption.args = {
  ...commonArgs,
  label: withRenderOptionLabel,
  placeholder: withRenderOtionPlaceholder,
  renderOption(a) {
    return (
      <Flex row overrideStyle={uikitStyles.renderOptionStyles}>
        <Text>Id of </Text>
        <Text color="theme">{a.label}</Text>
        <Text> is </Text>
        <Text color="theme">{a.id}.</Text>
      </Flex>
    );
  },
};

export const disabled = Template.bind({});

disabled.args = {
  ...commonArgs,
  label: disabledLabel,
  placeholder: disabledPlaceholder,
  disabled: true,
};

export default {
  title: 'Components/SelectTag',
  component: StoriesComponent,
};
