
import type { SelectTagValue, list, MultiOptionsEntity, OptionsEntity } from './SelectTag.types';

type HandleSelectedOptionType = {
  value: SelectTagValue;
  selectOptions: MultiOptionsEntity[];
  stringifyValueKey: string;
  stringifyLabelKey: string;
};
type HandleCheckedAppendType = {
  options: list[];
  value: SelectTagValue;
  stringifyValueKey: string;
};

type HandleMultiSelectArray = {
  selectedOption: list[];
  stringifyLabelKey: string;
  stringifyValueKey: string;
};
export const handleDisplayValue = (
  selectedOption: MultiOptionsEntity[],
  labelkey: string,
) => {
  const filteredValue = selectedOption.filter((option) => option.isChecked);
  return filteredValue.map((option) => {
    const opt = option as OptionsEntity;
    return opt[labelkey];
  });
};

export const handleMultiSelectArray = ({
  selectedOption,
  stringifyLabelKey,
  stringifyValueKey,
}: HandleMultiSelectArray) => {
  const labelArray = handleDisplayValue(selectedOption, stringifyLabelKey);
  const valueArray = handleDisplayValue(selectedOption, stringifyValueKey);
  return {
    labelArray,
    valueArray,
  };
};

export const checkedAppendFunction = ({
  options,
  value,
  stringifyValueKey,
}: HandleCheckedAppendType) =>
  options.map((opt) => {
    if (Array.isArray(value) && value.includes(opt[stringifyValueKey])) {
      return { ...opt, isChecked: true };
    }
    return { ...opt, isChecked: false };
  });

export const handleSelectedOption = ({
  value,
  selectOptions,
  stringifyValueKey,
  stringifyLabelKey,
}: HandleSelectedOptionType) => {
  const selectedOption = selectOptions.map((option) => {
    if (`${value}` === `${option[stringifyValueKey]}` && !option.isChecked) {
      return { ...option, isChecked: true };
    }
    if (`${value}` === `${option[stringifyValueKey]}` && option.isChecked) {
      return { ...option, isChecked: false };
    }
    return { ...option };
  });
  const { labelArray, valueArray } = handleMultiSelectArray({
    selectedOption,
    stringifyLabelKey,
    stringifyValueKey,
  });
  return {
    selectedOption,
    labelArray,
    valueArray,
  };
};
