import React, {useState, useEffect} from 'react';
import {StyleSheet, ViewStyle, View, TouchableOpacity} from 'react-native';
import SvgClose from '../icons/SvgClose';
import Flex from '../Flex/Flex';
import Text from '../Text/Text';
import {
  SEMANTIC_INFO_BLUE_PRIMARY,
  SEMANTIC_RED_PRIMARY,
  SEMANTIC_SUCCESS_GREEN_PRIMARY,
  SEMANTIC_WARNING_ORANGE_PRIMARY,
} from '../UikitUtils/colors';

type Styles = {
  snackbar: ViewStyle;
  error: ViewStyle;
  info: ViewStyle;
  success: ViewStyle;
  warning: ViewStyle;
};

const styles = StyleSheet.create<Styles>({
  snackbar: {
    paddingHorizontal: 12,
    paddingVertical: 12,
  },
  error: {
    backgroundColor: SEMANTIC_RED_PRIMARY,
  },
  info: {
    backgroundColor: SEMANTIC_INFO_BLUE_PRIMARY,
  },

  success: {
    backgroundColor: SEMANTIC_SUCCESS_GREEN_PRIMARY,
  },
  warning: {
    backgroundColor: SEMANTIC_WARNING_ORANGE_PRIMARY,
  },
});

type Props = {
  message: string;
  type?: 'error' | 'info' | 'success' | 'warning';
  onClear?: Function;
};

const SnackBar = ({message, type, onClear}: Props) => {
  const typedMessage = typeof message === 'string' ? message : '';
  const [showText, setShowText] = useState(true);

  useEffect(() => {
    if (!showText && typedMessage) {
      setShowText(true);
    }
  }, [typedMessage]);

  const styleArray = [styles.snackbar];
  if (type === 'error') {
    styleArray.push(styles.error);
  } else if (type === 'success') {
    styleArray.push(styles.success);
  } else if (type === 'warning') {
    styleArray.push(styles.warning);
  } else {
    styleArray.push(styles.info);
  }

  const hideSnackBar = () => {
    setShowText(false);
    if (typeof onClear === 'function') {
      onClear();
    }
  };

  return showText && typedMessage ? (
    <Flex row middle between overrideStyle={styleArray}>
      <Text color="white">{typedMessage}</Text>
      <TouchableOpacity testID="snackBarPress" onPress={hideSnackBar}>
        <Flex flex={1} middle center>
          <SvgClose width={16} height={16} />
        </Flex>
      </TouchableOpacity>
    </Flex>
  ) : (
    <View testID="emptyView" />
  );
};

export default SnackBar;
