import React, {useEffect, useRef, useCallback, useContext} from 'react';
import {Animated, Easing, TouchableOpacity} from 'react-native';
import Flex from '../Flex/Flex';
import SvgSwitchOff from '../icons/SvgSwitchOff';
import SvgSwitchOn from '../icons/SvgSwitchOn';
import ThemeContext from '../ThemeContext/ThemeContext';
import {primaryColor} from '../UikitUtils/themeHelper';
import {isEmpty} from '../UikitUtils/validators';

type DefaultPropsTypes = {
  name?: string;
};

const defaultProps: DefaultPropsTypes = {
  name: '',
};

type Props = {
  onClick?: (args: any) => void;
  onBlur?: (args: any) => void;
  checked?: boolean;
  color?: string;
  size?: number;
} & typeof defaultProps;

const Switch = ({onClick, onBlur, name, checked, size, color}: Props) => {
  const currentValue = useRef(new Animated.Value(0)).current;
  const {theme} = useContext(ThemeContext);
  const handleOnClick = useCallback(
    (e: any) => {
      if (typeof onClick === 'function' && e) {
        e.target.value = name;
        onClick(e);
      }
    },
    [onClick],
  );

  useEffect(() => {
    if (checked === true) {
      Animated.timing(currentValue, {
        toValue: 0.8,
        duration: 20,
        easing: Easing.in(Easing.bounce),
        useNativeDriver: false,
      }).start(() => {
        Animated.spring(currentValue, {
          toValue: 1,
          useNativeDriver: false,
        }).start();
      });
    }
  }, [checked]);

  let colors;
  if (isEmpty(color)) {
    colors = primaryColor(theme);
  } else {
    colors = color;
  }
  return (
    <TouchableOpacity
      testID="Switch"
      onPress={handleOnClick}
      onBlur={onBlur}
      activeOpacity={1}
    >
      <Flex row center>
        {checked ? (
          <Animated.View style={{transform: [{scale: currentValue}]}}>
            <SvgSwitchOn scale={size} fill={colors} />
          </Animated.View>
        ) : (
          <SvgSwitchOff scale={size} />
        )}
      </Flex>
    </TouchableOpacity>
  );
};

Switch.defaultProps = {
  size: 1,
};

export default Switch;
