import {TextStyle} from 'react-native';
import {
  BLACK,
  GRAY_60,
  SEMANTIC_INFO_BLUE_PRIMARY,
  SEMANTIC_RED_PRIMARY,
  SEMANTIC_SUCCESS_GREEN_PRIMARY,
  SEMANTIC_WARNING_ORANGE_PRIMARY,
  WHITE,
} from '../UikitUtils/colors';
import {
  linkTextColor,
  primaryTextColor,
  textThemeColor,
} from '../UikitUtils/themeHelper';
import type {ThemeType} from '../UikitUtils/themeTypes';
import {
  isTextColorKey,
  isTextStyleKey,
  textColors,
  textTransForm,
  textAlignForm,
} from './Text';
import {styles} from './textStyle';

type TextHelperArgsType = {
  color: textColors;
  flex?: number;
  bold?: boolean;
  italic?: boolean;
  underline?: boolean;
  transform?: textTransForm;
  align?: textAlignForm;
};

export const textHelper = ({
  color,
  flex,
  bold,
  italic,
  underline,
  transform,
  align,
}: TextHelperArgsType) => {
  const styleArray: TextStyle[] = [];
  if (flex) {
    styleArray.push({flex});
  }

  if (color === 'link') {
    styleArray.push(styles.bold);
  }

  if (bold) {
    styleArray.push(styles.bold);
  }

  if (italic) {
    styleArray.push(styles.italic);
  }

  if (underline) {
    styleArray.push(styles.underline);
  }

  if (isTextStyleKey(transform)) {
    styleArray.push(styles[transform]);
  }
  if (isTextStyleKey(align)) {
    styleArray.push(styles[align]);
  }
  return styleArray;
};

export const textColorHelper = (theme: ThemeType, color?: textColors) => {
  let textColor = '';
  if (isTextColorKey(color)) {
    switch (color) {
      case 'primary':
        textColor = primaryTextColor(theme);
        break;
      case 'theme':
        textColor = textThemeColor(theme);
        break;
      case 'error':
        textColor = SEMANTIC_RED_PRIMARY;
        break;
      case 'gray':
        textColor = GRAY_60;
        break;
      case 'link':
        textColor = linkTextColor(theme);
        break;
      case 'info':
        textColor = SEMANTIC_INFO_BLUE_PRIMARY;
        break;
      case 'black':
        textColor = BLACK;
        break;
      case 'warning':
        textColor = SEMANTIC_WARNING_ORANGE_PRIMARY;
        break;
      case 'white':
        textColor = WHITE;
        break;
      case 'success':
        textColor = SEMANTIC_SUCCESS_GREEN_PRIMARY;
        break;
      default:
        textColor = primaryTextColor(theme);
        break;
    }
  }
  return textColor;
};
