import React, {useState} from 'react';
import type {ReactNode} from 'react';
import ThemeContext from '../ThemeContext/ThemeContext';
import type {ToastParams} from '../ThemeContext/ThemeContext';
import {ThemeType} from '../UikitUtils/themeTypes';
import ThemeWrapper from './ThemeWrapper';
import ToastBar, {Insets} from '../Toast/ToastBar';

type Props = {
  children: ReactNode;
  theme: ThemeType;
  insets?: Insets;
};

const ThemeProvider = ({children, theme, insets}: Props) => {
  const [toastInfo, setToastInfo] = useState<ToastParams>({
    message: '',
    duration: 'SHORT',
    position: 'BOTTOM',
    type: 'BASIC',
  });

  const handleShowToast = (arg: ToastParams) => {
    setToastInfo({...toastInfo, ...arg});
  };
  return (
    <ThemeContext.Provider value={{theme, showToast: handleShowToast}}>
      <ThemeWrapper
        message={toastInfo.message}
        duration={toastInfo.duration}
        position={toastInfo.position}
        type={toastInfo.type}
        theme={theme}
      >
        <>
          <ToastBar insets={insets} />
          {children}
        </>
      </ThemeWrapper>
    </ThemeContext.Provider>
  );
};

export default ThemeProvider;
