import React, {useEffect, useRef, useState} from 'react';
import type {MutableRefObject, ReactNode} from 'react';
import {StyleSheet, Text, ViewStyle} from 'react-native';
import Flex from '../Flex/Flex';
import type {
  DurationTypes,
  ToastBarType,
  ToastPositionType,
} from '../ThemeContext/ThemeContext';
import {ThemeType} from '../UikitUtils/themeTypes';

const DEFAULT_DURATION = 5000;
type Styles = {
  snackbar: ViewStyle;
  error: ViewStyle;
  info: ViewStyle;
};

const styles = StyleSheet.create<Styles>({
  snackbar: {
    padding: 12,
  },
  error: {
    backgroundColor: 'red',
  },
  info: {
    backgroundColor: 'blue',
  },
});

type Props = {
  children: ReactNode;
  message: string;
  type: ToastBarType;
  duration: DurationTypes;
  position: ToastPositionType;
  theme: ThemeType;
};

const SnackBar = ({
  message,
  type,
  theme,
}: {
  message?: string;
  type?: ToastBarType;
  theme: ThemeType;
}) => {
  console.log('theme', theme);

  const styleArray = [styles.snackbar];
  if (type === 'ERROR') {
    styleArray.push(styles.error);
  } else if (type === 'SUCCESS') {
    styleArray.push({backgroundColor: 'green'});
  } else if (type === 'INFO') {
    styleArray.push(styles.info);
  } else {
    styleArray.push({backgroundColor: 'black'});
  }
  return (
    <Flex testID="snack" middle overrideStyle={styleArray}>
      <Text>{message}</Text>
    </Flex>
  );
};

const ThemeWrapper = ({
  children,
  type,
  duration,
  message,
  position,
  theme,
}: Props) => {
  const snackBarRef: MutableRefObject<any> = useRef(null);

  const [isSnack, setSnack] = useState(false);

  const handleCloseSnack = () => {
    const timmerDuration = duration === 'SHORT' ? 2000 : 5000;
    snackBarRef.current = setTimeout(() => {
      setSnack(false);
    }, timmerDuration);
  };

  useEffect(() => {
    if (message) {
      setSnack(true);
      handleCloseSnack();
    }
    return () => {
      if (snackBarRef.current) clearInterval(snackBarRef.current);
    };
  }, [message]);

  return (
    <>
      {isSnack && position === 'TOP' && (
        <SnackBar message={message} type={type} theme={theme} />
      )}
      <>{children}</>
      {isSnack && position === 'BOTTOM' && (
        <SnackBar message={message} type={type} theme={theme} />
      )}
    </>
  );
};

ThemeWrapper.defaultProps = {
  type: 'BASIC',
  duration: DEFAULT_DURATION,
  position: 'BOTTOM',
};

export default ThemeWrapper;
