/* eslint-env browser */
import * as Colors from './colors';
import {APP_THEME, CHURCH_THEME, DRUG_THEME} from './constants';
import {ThemeType} from './themeTypes';

// <<<<<<< START PRIMARY COLOR >>>>>>>
export const primaryDarkColor = (theme: ThemeType) => {
  switch (theme) {
    case DRUG_THEME:
      return '#5173fe';
    case CHURCH_THEME:
      return '#191A3E';
    default:
      return '#00347C';
  }
};
export const primaryColor = (theme: ThemeType) => {
  switch (theme) {
    case DRUG_THEME:
      return '#5168FF';
    case CHURCH_THEME:
      return '#232559';
    default:
      return '#0046A0';
  }
};
export const primaryTint1Color = (theme: ThemeType) => {
  switch (theme) {
    case DRUG_THEME:
      return '#2BAED5';
    case CHURCH_THEME:
      return '#4F517A';
    default:
      return '#448AFF';
  }
};
export const primaryTint2Color = (theme: ThemeType) => {
  switch (theme) {
    case DRUG_THEME:
      return '#519ef9';
    case CHURCH_THEME:
      return '#7B7C9B';
    default:
      return '#95C3FF';
  }
};
export const primaryTint3Color = (theme: ThemeType) => {
  switch (theme) {
    case DRUG_THEME:
      return '#B5DBFF';
    case CHURCH_THEME:
      return '#A7A8BD';
    default:
      return '#CCE2FF';
  }
};

export const primaryTint4Color = (theme: ThemeType) => {
  switch (theme) {
    case DRUG_THEME:
      return '#b5dbff';
    case CHURCH_THEME:
      return '#F9F9F9';
    default:
      return '#F2F8FF';
  }
};
// <<<<<<< END PRIMARY COLOR >>>>>>>

// <<<<<<< START SECONDARY COLOR >>>>>>>
export const secondaryDarkColor = (theme: ThemeType) => {
  switch (theme) {
    case DRUG_THEME:
      return '#00C853';
    case CHURCH_THEME:
      return '#A93E1D';
    default:
      return '#00C853';
  }
};

export const secondaryColor = (theme: ThemeType) => {
  switch (theme) {
    case DRUG_THEME:
      return '#E73785';
    case CHURCH_THEME:
      return '#F25929';
    default:
      return '#32FF14';
  }
};

export const secondaryTint1Color = (theme: ThemeType) => {
  switch (theme) {
    case DRUG_THEME:
      return '#80FF6D';
    case CHURCH_THEME:
      return '#F57A54';
    default:
      return '#80FF6D';
  }
};

export const secondaryTint2Color = (theme: ThemeType) => {
  switch (theme) {
    case DRUG_THEME:
      return '#97FF88';
    case CHURCH_THEME:
      return '#F79B7F';
    default:
      return '#97FF88';
  }
};

export const secondaryTint3Color = (theme: ThemeType) => {
  switch (theme) {
    case DRUG_THEME:
      return '#D3FFCC';
    case CHURCH_THEME:
      return '#FABDA9';
    default:
      return '#D3FFCC';
  }
};

export const secondaryTint4Color = (theme: ThemeType) => {
  switch (theme) {
    case DRUG_THEME:
      return '#E9FFE5';
    case CHURCH_THEME:
      return '#FEEEEA';
    default:
      return '#E9FFE5';
  }
};
// <<<<<<< END SECONDARY COLOR >>>>>>>

// <<<<<<< START BUTTON COLOR >>>>>>>

export const primaryButtonColor = (theme: ThemeType) => {
  switch (theme) {
    case DRUG_THEME:
      return '#2BAED5';
    case CHURCH_THEME:
      return '#f25929';
    default:
      return '#0046A0';
  }
};

export const primaryButtonTextColor = (theme: ThemeType) => {
  switch (theme) {
    case DRUG_THEME:
      return 'white';
    case APP_THEME:
      return 'white';
    case CHURCH_THEME:
      return 'white';
    default:
      return 'primary';
  }
};

export const secondaryButtonTextColor = (theme: ThemeType) => {
  switch (theme) {
    case DRUG_THEME:
      return 'theme';
    case APP_THEME:
      return 'theme';
    case CHURCH_THEME:
      return 'theme';
    default:
      return 'primary';
  }
};

export const defaultButtonCurved = (theme: ThemeType) => {
  switch (theme) {
    case DRUG_THEME:
      return false;
    case CHURCH_THEME:
      return true;
    default:
      return true;
  }
};

// <<<<<<< END BUTTON COLOR >>>>>>>

// <<<<<<< START TEXT COLOR THEME BASED >>>>>>>
// normal text color black shade
export const primaryTextColor = (theme: ThemeType) => {
  switch (theme) {
    case DRUG_THEME:
      return Colors.GRAY_10;
    default:
      return Colors.GRAY_10;
  }
};

// theme color like bule or pink
export const textThemeColor = (theme: ThemeType) => {
  switch (theme) {
    default:
      return primaryButtonColor(theme);
  }
};

export const linkTextColor = (theme: ThemeType) => {
  switch (theme) {
    case DRUG_THEME:
      return '#00529C';
    case APP_THEME:
      return primaryTint1Color(APP_THEME);
    default:
      return primaryTint1Color(APP_THEME);
  }
};
// <<<<<<< END TEXT COLOR THEME BASED >>>>>>>

// Input Helper
export const curvedDefaultInputHelper = (theme: ThemeType) => {
  switch (theme) {
    case DRUG_THEME:
    default:
      return true;
  }
};

// DON'T USE THIS IN UI COMPONENTS

export const getColors = (theme: ThemeType) => ({
  ...Colors,
  PRIMARY_DARK_COLOR: primaryDarkColor(theme),
  PRIMARY_COLOR: primaryColor(theme),
  PRIMARY_TINT_1_COLOR: primaryTint1Color(theme),
  PRIMARY_TINT_2_COLOR: primaryTint2Color(theme),
  PRIMARY_TINT_3_COLOR: primaryTint3Color(theme),
  PRIMARY_TINT_4_COLOR: primaryTint4Color(theme),
  SECONDARY_DARK_COLOR: secondaryDarkColor(theme),
  SECONDARY_COLOR: secondaryColor(theme),
  SECONDARY_TINT_1_COLOR: secondaryTint1Color(theme),
  SECONDARY_TINT_2_COLOR: secondaryTint2Color(theme),
  SECONDARY_TINT_3_COLOR: secondaryTint3Color(theme),
  SECONDARY_TINT_4_COLOR: secondaryTint4Color(theme),
  PRIMARY_TEXT_COLOR: primaryTextColor(theme),
  THEME_TEXT_COLOR: textThemeColor(theme),
  PRIMARY_BUTTON_TEXT_COLOR: primaryButtonTextColor(theme),
  SECONDARY_BUTTON_TEXT_COLOR: secondaryButtonTextColor(theme),
  LINK_TEXT_COLOR: linkTextColor(theme),
});

// export const generateCssColorVars = (theme: ThemeType) => {
//   if (typeof Window === 'undefined') {
//     return;
//   }
//   let style = '';
//   const colors: any = getColors(theme);
//   const root = document.querySelector(':root');
//   Object.keys(colors).map((colorKey) => {
//     if (root) {
//       style += `--color-${colorKey}:${colors[colorKey]};`;
//       root.setAttribute('style', style);
//     }
//     return null;
//   });
// };
