import {Platform} from 'react-native';
import type {IsEmptyValueType} from './validatorsTypes';

export const isEmpty = (value: IsEmptyValueType): boolean =>
  value === undefined || value === null || value === '';

export const secureImage = (imageUrl: string) => {
  if (isEmpty(imageUrl)) {
    return '';
  }
  if (Platform.OS === 'web') {
    return imageUrl.replace(/(http:\/\/)/, '//').replace(/\s/g, '%20');
  }
  return imageUrl.replace(/(http:\/\/)/, 'https://').replace(/\s/g, '%20');
};

export const isNumber = (value: string | number): boolean => {
  if (typeof value === 'string' || typeof value === 'number') {
    return value.toString().match(/^\d*$/) !== null;
  }
  return false;
};

export const isValidEmail = (value: string) => {
  if (typeof value === 'string') {
    return (
      value
        .trim()
        .match(/^([a-zA-Z0-9_\-\.]+)@([a-zA-Z0-9_\-\.]+)\.([a-zA-Z]{2,5})$/) !==
      null
    );
  }
  return false;
};
